pub struct SyncRequest {
pub source: SyncSource,
pub ignore: Vec<String>,
pub no_save: bool,
pub snapshot: bool,
pub use_cache: bool,
pub force: bool,
}Expand description
Request to sync a codebase (local or remote).
Fields
source: SyncSourceThe source to sync from.
ignore: Vec<String>Repositories to ignore when syncing an org.
no_save: boolWhether to skip saving to .self folder.
snapshot: boolWhether to create a timestamped snapshot.
use_cache: boolClone to global cache directory instead of current directory.
force: boolWhether to force a fresh sync even if .self exists.
Implementations
Sourceimpl SyncRequest
impl SyncRequest
Sourcepub fn github_org(org: impl Into<String>) -> Self
pub fn github_org(org: impl Into<String>) -> Self
Create a sync request for a GitHub organization.
Sourcepub fn github_repo(owner: impl Into<String>, repo: impl Into<String>) -> Self
pub fn github_repo(owner: impl Into<String>, repo: impl Into<String>) -> Self
Create a sync request for a GitHub repository.
Sourcepub fn with_ignore(
self,
ignore: impl IntoIterator<Item = impl Into<String>>,
) -> Self
pub fn with_ignore( self, ignore: impl IntoIterator<Item = impl Into<String>>, ) -> Self
Add repositories to ignore.
Sourcepub fn without_save(self) -> Self
pub fn without_save(self) -> Self
Skip saving to .self folder.
Sourcepub fn with_snapshot(self) -> Self
pub fn with_snapshot(self) -> Self
Create a snapshot after sync.